summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorRandall Spangler <rspangler@chromium.org>2012-10-03 15:09:08 -0700
committerGerrit <chrome-bot@google.com>2012-10-04 09:30:59 -0700
commita9e8f809a33d23430c87cc1944c9c37a015aee91 (patch)
treedc29c04592d4647184ef3c3407f1f025f16b4daf /include
parent66dda8936e4e72eab0d644a0754d52f7ddc1eb70 (diff)
downloadchrome-ec-a9e8f809a33d23430c87cc1944c9c37a015aee91.tar.gz
link: add hibernate option to ectool reboot_ec
This enables the OS to request the EC drop into its lowest-power shutdown state. Targeted at end of factory flow, where the at-shutdown variant is the desired variant because it allows the main processor to shut down cleanly first. BUG=chrome-os-partner:14838 BRANCH=link TEST=from root shell, ectool reboot_ec hibernate at-shutdown shutdown -h now System should shut down, and EC console should be unresponsive (since it's hibernating). Press power button, and system should power back on. ectool reboot_ec hibernate System should shut down immediately. Press power button, and system should power back on. Change-Id: I8084a3a1bca6b7c201e090552b193fe1568708a2 Signed-off-by: Randall Spangler <rspangler@chromium.org> Reviewed-on: https://gerrit.chromium.org/gerrit/34569 Reviewed-by: Vic Yang <victoryang@chromium.org>
Diffstat (limited to 'include')
-rw-r--r--include/ec_commands.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/include/ec_commands.h b/include/ec_commands.h
index ac7a06893f..42882cba5d 100644
--- a/include/ec_commands.h
+++ b/include/ec_commands.h
@@ -1038,11 +1038,12 @@ struct ec_params_force_idle {
/* Command */
enum ec_reboot_cmd {
EC_REBOOT_CANCEL = 0, /* Cancel a pending reboot */
- EC_REBOOT_JUMP_RO, /* Jump to RO without rebooting */
- EC_REBOOT_JUMP_RW, /* Jump to RW without rebooting */
+ EC_REBOOT_JUMP_RO = 1, /* Jump to RO without rebooting */
+ EC_REBOOT_JUMP_RW = 2, /* Jump to RW without rebooting */
/* (command 3 was jump to RW-B) */
EC_REBOOT_COLD = 4, /* Cold-reboot */
- EC_REBOOT_DISABLE_JUMP, /* Disable jump until next reboot */
+ EC_REBOOT_DISABLE_JUMP = 5, /* Disable jump until next reboot */
+ EC_REBOOT_HIBERNATE = 6 /* Hibernate EC */
};
/* Flags for ec_params_reboot_ec.reboot_flags */